<?php

namespace TDevAgency\FilesManager\Jobs;

use Exception;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use TDevAgency\FilesManager\Helpers\CacheHelper;
use TDevAgency\FilesManager\Helpers\GenerateSizesHelper;
use TDevAgency\FilesManager\Helpers\SymlinkHelper;
use TDevAgency\FilesManager\ResourceModels\TdfmFile;

class FilesManagerGenerateSizeJob implements ShouldQueue
{
    use Dispatchable;
    use InteractsWithQueue;
    use Queueable;
    use SerializesModels;

    /** @var TdfmFile $file */
    private $file;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct(TdfmFile $file)
    {
        $this->file = $file;
    }

    /**
     * Execute the job.
     *
     * @return void
     * @throws Exception
     */
    public function handle(): void
    {
        app(GenerateSizesHelper::class)->handle($this->file);
        app(SymlinkHelper::class)->symlinkFile($this->file);
        app(CacheHelper::class)->removeFileData($this->file->id);
    }
}
